# Python API for WiLight devices in Home Assistant

A simple Python API for controlling devices from WiLight, developed for integration with Home Assistant. At present, the following devices are currently supported:

- I-100
- I-102
- C-103
- V-104
- R-105
- I-107
- I-110

TCP client with some ideas of [hlk-sw16](https://github.com/jameshilliard/hlk-sw16).
Discovery based on [pywemo](https://github.com/pavoni/pywemo).
Thanks to the contributors.
